==> cms_content_sync-8.x-1.27.tar.gz: cms_content_sync/src/Plugin/cms_content_sync/field_handler/DefaultLayoutBuilderHandler.php <==
<?php

namespace Drupal\cms_content_sync\Plugin\cms_content_sync\field_handler;

use Drupal\cms_content_sync\ExportIntent;
use Drupal\cms_content_sync\ImportIntent;
use Drupal\cms_content_sync\Plugin\FieldHandlerBase;
use Drupal\cms_content_sync\SyncIntent;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\layout_builder\Section;

/**
 * Providing a minimalistic implementation for any field type.
 *
 * @FieldHandler(
 *   id = "cms_content_sync_default_layout_builder",
 *   label = @Translation("Default Layout Builder"),
 *   weight = 100
 * )
 *
 * @package Drupal\cms_content_sync\Plugin\cms_content_sync\field_handler
 */
class DefaultLayoutBuilderHandler extends FieldHandlerBase {

  /**
   * {@inheritdoc}
   */
  public static function supports($entity_type, $bundle, $field_name, FieldDefinitionInterface $field) {
    return $field->getType() == "layout_section";
  }

  /**
   * @inheritdoc
   */
  public function export(ExportIntent $intent) {
    $action = $intent->getAction();
    $entity = $intent->getEntity();

    if ($this->settings['export'] != ExportIntent::EXPORT_AUTOMATICALLY) {
      return FALSE;
    }

    // Deletion doesn't require any action on field basis for static data.
    if ($action == SyncIntent::ACTION_DELETE) {
      return FALSE;
    }

    $layout_builder_elements = $entity->get($this->fieldName)->getValue();

    $layout_builder_array = [];
    foreach ($layout_builder_elements as $key => $layout_builder_element) {
      /**
       * @var $layout_builder_element \Drupal\layout_builder\Section
       */
      $serialize = $layout_builder_element['section']->toArray();

      if (isset($serialize['components'])) {
        foreach ($serialize['components'] as &$component) {
          if (isset($component['configuration']['provider'])) {
            if ($component['configuration']['provider'] == 'block_content') {
              list($provider, $uuid) = explode(':', $component['configuration']['id']);

              $block_storage = \Drupal::entityTypeManager()->getStorage('block_content');
              $block = $block_storage->loadByProperties(['uuid' => $uuid]);

              $component['configuration']['block_reference'] = $intent->embedEntity(reset($block), SyncIntent::ENTITY_REFERENCE_EXPORT_AS_DEPENDENCY);
            }
            elseif ($component['configuration']['provider'] == 'layout_builder') {

              if (isset($component['configuration']['block_revision_id'])) {
                $block_storage = \Drupal::entityTypeManager()->getStorage('block_content');
                $block = $block_storage->loadByProperties(['revision_id' => $component['configuration']['block_revision_id']]);

                unset($component['configuration']['block_revision_id']);

                $component['configuration']['block_reference'] = $intent->embedEntity(reset($block), SyncIntent::ENTITY_REFERENCE_EXPORT_AS_DEPENDENCY);
              }
            }
          }
        }
      }

      $layout_builder_array[$key] = $serialize;
    }

    if (!empty($layout_builder_array)) {
      $intent->setField($this->fieldName, $layout_builder_array);

      return TRUE;
    }
    else {
      return FALSE;
    }
  }

  /**
   *
   */
  public function import(ImportIntent $intent) {

    $layout_builder_array = $intent->getField($this->fieldName);
    if (!empty($layout_builder_array)) {
      $layout_builder_elements = [];
      foreach ($layout_builder_array as $key => $layout_builder_element) {

        if (isset($layout_builder_element['components'])) {
          foreach ($layout_builder_element['components'] as $uuid => $component) {
            if (isset($component['configuration']['provider'])) {

              if ($component['configuration']['provider'] == 'layout_builder') {
                $block = $intent->loadEmbeddedEntity($component['configuration']['block_reference']);

                if ($block) {
                  $layout_builder_element['components'][$uuid]['configuration']['block_revision_id'] = $block->get('revision_id')->value;
                }

              }

            }
          }
        }

        $layout_builder_elements[$key]['section'] = Section::fromArray($layout_builder_element);
      }

      $intent->getEntity()->set($this->fieldName, $layout_builder_elements);
    }
  }

}

==> cms_content_sync-8.x-1.33.tar.gz: cms_content_sync/src/Plugin/cms_content_sync/field_handler/DefaultLayoutBuilderHandler.php <==
<?php

namespace Drupal\cms_content_sync\Plugin\cms_content_sync\field_handler;

use Drupal\cms_content_sync\PushIntent;
use Drupal\cms_content_sync\PullIntent;
use Drupal\cms_content_sync\Plugin\FieldHandlerBase;
use Drupal\cms_content_sync\SyncIntent;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\layout_builder\Section;

/**
 * Providing a minimalistic implementation for any field type.
 *
 * @FieldHandler(
 *   id = "cms_content_sync_default_layout_builder",
 *   label = @Translation("Default Layout Builder"),
 *   weight = 100
 * )
 *
 * @package Drupal\cms_content_sync\Plugin\cms_content_sync\field_handler
 */
class DefaultLayoutBuilderHandler extends FieldHandlerBase {

  /**
   * {@inheritdoc}
   */
  public static function supports($entity_type, $bundle, $field_name, FieldDefinitionInterface $field) {
    return $field->getType() == "layout_section";
  }

  /**
   * @inheritdoc
   */
  public function push(PushIntent $intent) {
    $action = $intent->getAction();
    $entity = $intent->getEntity();

    if ($this->settings['export'] != PushIntent::PUSH_AUTOMATICALLY) {
      return FALSE;
    }

    // Deletion doesn't require any action on field basis for static data.
    if ($action == SyncIntent::ACTION_DELETE) {
      return FALSE;
    }

    $layout_builder_elements = $entity->get($this->fieldName)->getValue();

    $layout_builder_array = [];
    foreach ($layout_builder_elements as $key => $layout_builder_element) {
      /**
       * @var $layout_builder_element \Drupal\layout_builder\Section
       */
      $serialize = $layout_builder_element['section']->toArray();

      if (isset($serialize['components'])) {
        foreach ($serialize['components'] as &$component) {
          if (isset($component['configuration']['provider'])) {
            if ($component['configuration']['provider'] == 'block_content') {
              list($provider, $uuid) = explode(':', $component['configuration']['id']);

              $block_storage = \Drupal::entityTypeManager()->getStorage('block_content');
              $block = $block_storage->loadByProperties(['uuid' => $uuid]);

              $component['configuration']['block_reference'] = $intent->embedEntity(reset($block), SyncIntent::ENTITY_REFERENCE_PUSH_AS_DEPENDENCY);
            }
            elseif ($component['configuration']['provider'] == 'layout_builder') {

              if (isset($component['configuration']['block_revision_id'])) {
                $block_storage = \Drupal::entityTypeManager()->getStorage('block_content');
                $block = $block_storage->loadByProperties(['revision_id' => $component['configuration']['block_revision_id']]);

                unset($component['configuration']['block_revision_id']);

                $component['configuration']['block_reference'] = $intent->embedEntity(reset($block), SyncIntent::ENTITY_REFERENCE_PUSH_AS_DEPENDENCY);
              }
            }
          }
        }
      }

      $layout_builder_array[$key] = $serialize;
    }

    if (!empty($layout_builder_array)) {
      $intent->setField($this->fieldName, $layout_builder_array);

      return TRUE;
    }
    else {
      return FALSE;
    }
  }

  /**
   *
   */
  public function pull(PullIntent $intent) {

    $layout_builder_array = $intent->getField($this->fieldName);
    if (!empty($layout_builder_array)) {
      $layout_builder_elements = [];
      foreach ($layout_builder_array as $key => $layout_builder_element) {

        if (isset($layout_builder_element['components'])) {
          foreach ($layout_builder_element['components'] as $uuid => $component) {
            if (isset($component['configuration']['provider'])) {

              if ($component['configuration']['provider'] == 'layout_builder') {
                $block = $intent->loadEmbeddedEntity($component['configuration']['block_reference']);

                if ($block) {
                  $layout_builder_element['components'][$uuid]['configuration']['block_revision_id'] = $block->get('revision_id')->value;
                }

              }

            }
          }
        }

        $layout_builder_elements[$key]['section'] = Section::fromArray($layout_builder_element);
      }

      $intent->getEntity()->set($this->fieldName, $layout_builder_elements);
    }
  }

}
